@@ -16,12 +16,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: debian.rb,v 1.31 2002/01/06 14:42:24 ukai Exp $
+# $Id: debian.rb,v 1.33 2003/10/07 17:07:02 ukai Exp $
 #
 
 require 'debian/ar'
 require 'debian/utils'
 
+# ruby1.6 does not have Hash.values_at, but ruby1.8 prefers it
+unless Hash.new.respond_to? :values_at
+  class Hash
+   alias_method :values_at, :indexes
+  end
+end
+
 module Debian
   class Error < StandardError; end
   COMPONENT = ['main', 'contrib', 'non-free']
@@ -163,7 +170,7 @@ module Debian
 	line.chomp!
 	if /^\s/ =~ line
 	  if field == ''
-	    raise Debian::ControlError, 
+	    raise Debian::FieldError, 
 	      "E: invalid format #{line} in #{line}"
 	  end
 	  if wf.empty? || wf.find {|f| f.capitalize == field }
@@ -174,7 +181,7 @@ module Debian
 	  if wf.empty? || wf.find {|f| f.capitalize == field }
 	    @fields.push(field)
 	    if @info[field]
-	      raise Debian::ControlError, 
+	      raise Debian::FieldError, 
 		"E: duplicate control info #{field} in #{line}"
 	    end
 	    @info[field] = $2.strip
@@ -183,7 +190,7 @@ module Debian
       end
       rf.each {|f|
 	unless @info[f.capitalize]
-	  raise Debian::ControlError, 
+	  raise Debian::FieldError, 
 	    "E: required field #{f} not found in #{c}"
 	end
       }
@@ -507,7 +514,7 @@ module Debian
 	Debian::Utils.gunzip(ctz) {|ct|
 	  Debian::Utils.tar(ct, op, *pat) {|fp|
 	    if block_given?
-	      return yield fp
+	      return yield(fp)
 	    else
 	      return fp
 	    end
@@ -519,7 +526,7 @@ module Debian
     def control_fp(op, *pat)
       deb_fp("control.tar.gz", op, *pat) {|fp|
 	if block_given?
-	  return yield fp
+	  return yield(fp)
 	else
 	  return fp
 	end
@@ -528,7 +535,7 @@ module Debian
     def data_fp(op, *pat)
       deb_fp("data.tar.gz", op, *pat) {|fp|
 	if block_given?
-	  return yield fp
+	  return yield(fp)
 	else
 	  return fp
 	end
@@ -563,7 +570,7 @@ module Debian
       end
       control_fp(Debian::Utils::TAR_EXTRACT, "*/#{cfile}") {|fp|
 	if block_given?
-	  return yield fp
+	  return yield(fp)
 	else
 	  return fp
 	end
@@ -581,7 +588,7 @@ module Debian
       end
       data_fp(Debian::Utils::TAR_EXTRACT, pat) {|fp|
 	if block_given?
-	  return yield fp
+	  return yield(fp)
 	else
 	  return fp
 	end
@@ -597,7 +604,7 @@ module Debian
       @artab.open("data.tar.gz") {|dtz|
 	Debian::Utils.gunzip(dtz) {|dt|
 	  if block_given?
-	    return yield dt
+	    return yield(dt)
 	  else
 	    return dt
 	  end
@@ -730,11 +737,11 @@ module Debian
       return self
     end
     def + (da)
-      if self.type != da.type
+      if self.class != da.class
 	raise Debian::ArchiveError, 
-	  "E: `+' type mismatch #{self.type} != #{da.type}"
+	  "E: `+' type mismatch #{self.class} != #{da.class}"
       end
-      nda = self.type.new
+      nda = self.class.new
       nda.add(self)
       nda.add(da)
       nda
@@ -749,11 +756,11 @@ module Debian
       return self
     end
     def - (da)
-      if self.type != da.type
+      if self.class != da.class
 	raise Debian::ArchiveError,
-	  "E: `-' type mismatch #{self.type} != #{da.type}"
+              "E: `-' type mismatch #{self.class} != #{da.class}"
       end
-      nda = self.type.new
+      nda = self.class.new
       nda.add(self) # copy
       nda.sub(da)
       nda
@@ -776,17 +783,17 @@ module Debian
       return self
     end
     def & (da)
-      if self.type != da.type
+      if self.class != da.class
 	raise Debian::ArchiveError,
-	  "E: `-' type mismatch #{self.type} != #{da.type}"
+	  "E: `-' type mismatch #{self.class} != #{da.class}"
       end
-      nda = self.type.new
+      nda = self.class.new
       nda.intersect(self, da)
       nda
     end
 
     def <<(deb)
-      nda = self.type.new
+      nda = self.class.new
       nda.add(self)
       return nda unless deb
       nda[deb.package] = deb
@@ -806,7 +813,7 @@ module Debian
     end
     def store(package,deb) self[package] = deb; end
     def >>(deb)
-      nda = self.type.new
+      nda = self.class.new
       nda.add(self)
       return nda unless deb
       nda.delete_if {|pkg, d| d == deb }
@@ -856,7 +863,7 @@ module Debian
     def has_key?(pkg) @lists.has_key?(pkg); end
     def has_value?(deb) @lists.has_value?(deb); end
     def include?(key) has_key?(key); end
-    def indexes(*arg) @lists.indexes(*arg); end
+    def indexes(*arg) @lists.values_at(*arg); end
     def indices(*arg) @lists.indices(*arg); end
     def key?(pkg) has_key?(pkg); end
     def keys() @lists.keys; end
@@ -955,7 +962,7 @@ module Debian
       self
     end
     def +(p)
-      np = self.type.new
+      np = self.class.new
       np.add(self)
       np.add(p)
       np
@@ -971,7 +978,7 @@ module Debian
       self
     end
     def -(p)
-      np = self.type.new
+      np = self.class.new
       np.add(self)
       np.sub(p)
       np
@@ -985,13 +992,13 @@ module Debian
       self
     end
     def & (p)
-      np = self.type.new
+      np = self.class.new
       np.intersect(self, p)
       np
     end
 
     def <<(deb)
-      np = self.type.new
+      np = self.class.new
       np.add(self)
       if deb
 	np[deb.package] = deb
@@ -1005,7 +1012,7 @@ module Debian
       d
     end
     def >>(deb)
-      np = self.type.new
+      np = self.class.new
       np.add(self)
       if np.has_value?(deb)
 	np.delete(deb.package)
